<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="cs">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Program_Name</source>
        <translation>Program_Name</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="46"/>
        <source>Quit application</source>
        <translation>Ukončit aplikaci</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="49"/>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="56"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="88"/>
        <source>Display help </source>
        <translation>Zobrazit nápovědu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="91"/>
        <source>Help</source>
        <translation>Nápověda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="98"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="114"/>
        <source>Back</source>
        <translation>Zpět</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="172"/>
        <source>Next</source>
        <translation>Další</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="198"/>
        <source>About this application</source>
        <translation>O této aplikaci</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="201"/>
        <source>About...</source>
        <translation>O programu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="208"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="224"/>
        <source>View Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="259"/>
        <location filename="../mainwindow.cpp" line="490"/>
        <location filename="../mainwindow.cpp" line="511"/>
        <source>Select ISO</source>
        <translation>Vybrat ISO soubor</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="270"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select Target USB Device&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Vyberte cílové USB zařízení&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="280"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select ISO file&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Vyberte ISO soubor&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="309"/>
        <source>Advanced Options</source>
        <translation>Rozšířené možnosti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="327"/>
        <source>Make the ext4 filesystem even if one exists</source>
        <translation>Vytvořit ext4 souborový systém i když už existuje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="334"/>
        <source>Save the original boot directory when updating a live-usb</source>
        <translation>Při aktuallizaci live-usb ponechat původní bootovací složku </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="341"/>
        <source>Use gpt partitioning instead of msdos</source>
        <translation>použít rozdělení gpt místo msdos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="344"/>
        <source>GPT partitioning</source>
        <translation>Rozdělení GPT</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="351"/>
        <source>Update (only update an existing live-usb)</source>
        <translation>Update (pouze aktualizace live-usb)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="358"/>
        <source>Don&apos;t replace syslinux files</source>
        <translation>Nepřepisovat soubory syslinux</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="361"/>
        <source>Keep syslinux files</source>
        <translation>Ponechat soubory syslinux</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="368"/>
        <source>Ignore USB/removable check</source>
        <translation>Ignorovat kontrolu USB</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="375"/>
        <source>Temporarily disable automounting</source>
        <translation>Dočasně vypnout autopřipojení</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="385"/>
        <source>Set pmbr_boot disk flag (won&apos;t boot via UEFI)</source>
        <translation>Nastavit pmbr_boot disk flag (nenabootuje pod UEFI)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="392"/>
        <source>Don&apos;t use fuseiso to mount iso files</source>
        <translation>Nepoužívat fuseiso k připojení iso souborů</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="418"/>
        <source>Size of ESP (uefi) partition:</source>
        <translation>Velikost ESP (uefi) oddílu:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="438"/>
        <source>Verbosity (less to more):</source>
        <translation>Verbosita (méně nebo více):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="477"/>
        <source>vfat</source>
        <translation>vfat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="482"/>
        <source>exfat</source>
        <translation>exfat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="487"/>
        <source>ext4</source>
        <translation>ext4</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="492"/>
        <source>ntfs</source>
        <translation>ntfs</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="516"/>
        <source>Make separate data partition (percent)</source>
        <translation>Vytvořit separátní oddíl pro data (percent)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="523"/>
        <source>Format</source>
        <translation>Formát</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="533"/>
        <source>Refresh drive list</source>
        <translation>Obnovit seznam diskových jednotek</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="547"/>
        <location filename="../mainwindow.cpp" line="450"/>
        <source>Show advanced options</source>
        <translation>Zobrazit pokročilé možnosti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="567"/>
        <source>Mode</source>
        <translation>Módy USB</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="582"/>
        <source>Full-featured mode - writable Li&amp;veUSB</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="592"/>
        <source>Read-only, cannot be used with persistency</source>
        <translation>Read-only, nemůže být použito s persitencí</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="595"/>
        <source>Image &amp;mode - read-only LiveUSB (dd)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="609"/>
        <source>For distros other than antiX/MX use image mode (dd).</source>
        <translation>Pro ostatní distra, ne antiX/MX použijte Mód Image (dd).</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="657"/>
        <source>Options</source>
        <translation>Možnosti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="695"/>
        <source>Percent of USB-device to use:</source>
        <translation>Procent USB disku k použití:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="702"/>
        <source>Label ext partition:</source>
        <translation>Jméno ext oddílu:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="750"/>
        <source>Don&apos;t run commands that affect the usb device</source>
        <translation>Nezpustí příkazy, které by ovlivnili usb disk.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="753"/>
        <source>Dry run (no change to system)</source>
        <translation>Zkouška (beze změn v systému)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="760"/>
        <source>clone from a mounted live-usb or iso-file.</source>
        <translation>Klonování připojeného live-usb disku nebo iso-souboru</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="763"/>
        <source>Clone an existing live system</source>
        <translation>Naklonovat již existující live systém</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="770"/>
        <source>Set up to boot from an encrypted partition, will prompt for pass phrase on first boot</source>
        <translation>Nastaví bootování ze šifrovaného oddílu, při prvním startu bude vyžadováno heslo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="773"/>
        <source>Encrypt</source>
        <translation>Zašifrovat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="780"/>
        <source>Clone running live system</source>
        <translation>Naklonovat běžící live systém</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="76"/>
        <source>Confirmation</source>
        <translation>Potvrzení</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="77"/>
        <source>Target device %1 is larger than %2 GB. Do you wish to proceed?</source>
        <translation>Cílová jednotka %1 je větší než %2 GB. Chcete pokračovat?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="109"/>
        <location filename="../mainwindow.cpp" line="306"/>
        <location filename="../mainwindow.cpp" line="436"/>
        <source>Failure</source>
        <translation>Selhání</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="109"/>
        <source>Source and destination are on the same device, please select again.</source>
        <translation>Zdroj a cíl jsou na stejné jednotce, prosím proveďte vyběr znovu.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="144"/>
        <source>Writing %1 using 'dd' command to /dev/%2,

Please wait until the the process is completed</source>
        <translation>Zápis %1 s použitím příkazu &apos;dd&apos; na /dev/%2,

Čekejte až bude proces dokončen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="301"/>
        <source>Success</source>
        <translation>Úspěch!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="301"/>
        <source>LiveUSB creation successful!</source>
        <translation>Vytvoření Live-USB proběhlo úspěšně!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="306"/>
        <source>Error encountered in the LiveUSB creation process</source>
        <translation>Při procesu tvorby Live-USB došlo k chybě</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="364"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="364"/>
        <source>Please select a USB device to write to</source>
        <translation>Prosím vyberte USB jednotku k zápisu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="367"/>
        <source>These actions will destroy all data on 

</source>
        <translation>Tato akce zničí všechna data na 

</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="367"/>
        <source>Do you wish to continue?</source>
        <translation>Přejete si pokračovat?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="372"/>
        <location filename="../mainwindow.cpp" line="504"/>
        <source>clone</source>
        <translation>klonovat</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="399"/>
        <source>About %1</source>
        <translation>O programu %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="400"/>
        <source>Version: </source>
        <translation>Verze:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="401"/>
        <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
        <translation>Program pro tvorbu Live-USB z ISO, jiného Live-USB, Live-CD/DVD, nebo spuštěného live systému.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="403"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Vlastnická práva (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="404"/>
        <source>%1 License</source>
        <translation>Licence %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="411"/>
        <source>%1 Help</source>
        <translation>Nápověda %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="419"/>
        <source>Select an ISO file to write to the USB drive</source>
        <translation>Vyberte ISO soubor pro zápis na USB jednotku </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="420"/>
        <source>ISO Files (*.iso);;All Files (*.*)</source>
        <translation>ISO Soubor (*.iso);;Všechny soubory (*.*)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="430"/>
        <location filename="../mainwindow.cpp" line="486"/>
        <source>Select Source Directory</source>
        <translation>Vyberte zdrojový aresář</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="436"/>
        <source>Could not find %1/antiX/linuxfs file</source>
        <translation> %1/antiX/linuxfs soubor nenalezen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="456"/>
        <source>Hide advanced options</source>
        <translation>Skrýt pokročilé možnosti</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="485"/>
        <location filename="../mainwindow.cpp" line="502"/>
        <source>Select Source</source>
        <translation>Vyberte zdroj</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="489"/>
        <location filename="../mainwindow.cpp" line="509"/>
        <source>Select ISO file</source>
        <translation>Vyberte ISO soubor</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="576"/>
        <source>Could not find a log file at: </source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="41"/>
        <source>License</source>
        <translation>Licence</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <location filename="../about.cpp" line="51"/>
        <source>Changelog</source>
        <translation>Protokol změn</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="43"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="63"/>
        <source>&amp;Close</source>
        <translation>&amp;Zavřít</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="55"/>
        <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
        <translation>Program pro tvorbu Live-USB z ISO, jiného Live-USB, Live-CD/DVD, nebo spuštěného live systému.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>filename</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>Name of .iso file to open</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>[filename]</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../main.cpp" line="77"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="78"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Spuštěno pod účtem root-a, odhlašte se a přihlašte jako bězný uživatel.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="91"/>
        <source>version:</source>
        <translation>verze:</translation>
    </message>
</context>
</TS>